==> ejc-car-api-3.0.0-20231101.013113-46-sources.jar: com/ejianc/business/car/vo/WageUserDetailVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织人员登记-人员明细
 * 
 * @author generator
 * 
 */
public class WageUserDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long wageUserId; // 组织人员登记表主键
    private String wageName; // 姓名
    private BigDecimal baseSalary; // 基本薪资
    private BigDecimal jobSubsidy; // 岗位津贴
    private BigDecimal performance; // 绩效
    private String wageCard; // 银行卡号
    private String remark; // 备注
    

    public Long getWageUserId() {
        return wageUserId;
    }

    public void setWageUserId(Long wageUserId) {
        this.wageUserId = wageUserId;
    }
    public BigDecimal getBaseSalary() {
        return baseSalary;
    }

    public void setBaseSalary(BigDecimal baseSalary) {
        this.baseSalary = baseSalary;
    }
    public BigDecimal getJobSubsidy() {
        return jobSubsidy;
    }

    public void setJobSubsidy(BigDecimal jobSubsidy) {
        this.jobSubsidy = jobSubsidy;
    }
    public BigDecimal getPerformance() {
        return performance;
    }

    public void setPerformance(BigDecimal performance) {
        this.performance = performance;
    }
    public String getWageCard() {
        return wageCard;
    }

    public void setWageCard(String wageCard) {
        this.wageCard = wageCard;
    }
    public String getRemark() {
        return remark;
    }

    public String getWageName() {
        return wageName;
    }

    public void setWageName(String wageName) {
        this.wageName = wageName;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-car-api-3.0.0-20231206.094315-56-sources.jar: com/ejianc/business/car/vo/WageUserDetailVO.java <==
package com.ejianc.business.car.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 组织人员登记-人员明细
 * 
 * @author generator
 * 
 */
public class WageUserDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long wageUserId; // 组织人员登记表主键
    private String wageName; // 姓名
    private BigDecimal baseSalary; // 基本薪资
    private BigDecimal jobSubsidy; // 岗位津贴
    private BigDecimal performance; // 绩效
    private String wageCard; // 银行卡号
    private String remark; // 备注
    private String errorMessage;
    

    public Long getWageUserId() {
        return wageUserId;
    }

    public void setWageUserId(Long wageUserId) {
        this.wageUserId = wageUserId;
    }
    public BigDecimal getBaseSalary() {
        return baseSalary;
    }

    public void setBaseSalary(BigDecimal baseSalary) {
        this.baseSalary = baseSalary;
    }
    public BigDecimal getJobSubsidy() {
        return jobSubsidy;
    }

    public void setJobSubsidy(BigDecimal jobSubsidy) {
        this.jobSubsidy = jobSubsidy;
    }
    public BigDecimal getPerformance() {
        return performance;
    }

    public void setPerformance(BigDecimal performance) {
        this.performance = performance;
    }
    public String getWageCard() {
        return wageCard;
    }

    public void setWageCard(String wageCard) {
        this.wageCard = wageCard;
    }
    public String getRemark() {
        return remark;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getWageName() {
        return wageName;
    }

    public void setWageName(String wageName) {
        this.wageName = wageName;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
